package main

import (
	"context"
	"log"

	"github.com/gofiber/fiber/v3"
	"worklog/db"
	"worklog/repository"
)

func main() {
	DB, err := db.Init()

	if err != nil {
		log.Fatal(err)
	}

	repo := repository.GetUserRepo(DB)
	ctx := context.Background()

	users, totalUserCount, err := repo.List(ctx, 0, 10)
	if err != nil {
		log.Println(err)
	}

	log.Printf("Fetched %d users", len(users))
	log.Printf("%d total users", totalUserCount)

	app := fiber.New()

	app.Get("/", func(c fiber.Ctx) error {
		return c.SendString("Hello, World 👋!")
	})

	log.Fatal(app.Listen(":3000"))
}
